@@ -412,8 +412,11 @@ namespace cxxopts
 
   namespace values
   {
-    std::basic_regex<char> integer_pattern
-      ("(-)?(0x)?([1-9a-zA-Z][0-9a-zA-Z]*)|(0)");
+    namespace
+    {
+      std::basic_regex<char> integer_pattern
+        ("(-)?(0x)?([1-9a-zA-Z][0-9a-zA-Z]*)|(0)");
+    }
 
     namespace detail
     {
@@ -530,48 +533,66 @@ namespace cxxopts
       }
     }
 
+    template <typename T>
+    void stringstream_parser(const std::string& text, T& value)
+    {
+      std::stringstream in(text);
+      in >> value;
+      if (!in) {
+        throw argument_incorrect_type(text);
+      }
+    }
+
+    inline
     void
     parse_value(const std::string& text, uint8_t& value)
     {
       integer_parser(text, value);
     }
 
+    inline
     void
     parse_value(const std::string& text, int8_t& value)
     {
       integer_parser(text, value);
     }
 
+    inline
     void
     parse_value(const std::string& text, uint16_t& value)
     {
       integer_parser(text, value);
     }
 
+    inline
     void
     parse_value(const std::string& text, int16_t& value)
     {
       integer_parser(text, value);
     }
 
+    inline
     void
     parse_value(const std::string& text, uint32_t& value)
     {
       integer_parser(text, value);
     }
 
+    inline
     void
     parse_value(const std::string& text, int32_t& value)
     {
       integer_parser(text, value);
     }
 
+    inline
     void
     parse_value(const std::string& text, uint64_t& value)
     {
       integer_parser(text, value);
     }
 
+    inline
     void
     parse_value(const std::string& text, int64_t& value)
     {
@@ -594,6 +615,15 @@ namespace cxxopts
       value = text;
     }
 
+    // The fallback parser. It uses the stringstream parser to parse all types
+    // that have not been overloaded explicitly.  It has to be placed in the
+    // source code before all other more specialized templates.
+    template <typename T>
+    void
+    parse_value(const std::string& text, T& value) {
+      stringstream_parser(text, value);
+    }
+
     template <typename T>
     void
     parse_value(const std::string& text, std::vector<T>& value)
